FlutterEssentialsKitLocalizationsEn class

The translations for English (en).

Inheritance

Constructors

FlutterEssentialsKitLocalizationsEn([String locale = 'en'])

Properties

hashCode → int
The hash code for this object.
no setterinherited
localeName → String
finalinherited
ruleConfirmed → String
The rule confirmed error message
no setteroverride
ruleEmail → String
The rule email error message
no setteroverride
ruleRegex → String
The rule regex error message
no setteroverride
ruleRequired → String
The rule required error message
no setteroverride
ruleSame → String
The rule same error message
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ruleMaxListLength(num max) → String
The rule max list length error message
override
ruleMaxNumber(num max) → String
The rule max number error message
override
ruleMaxStringLength(num max) → String
The rule max string error message
override
ruleMinListLength(num min) → String
The rule min list length error message
override
ruleMinNumber(num min) → String
The rule min number error message
override
ruleMinStringLength(num min) → String
The rule min string error message
override
ruleSizeListLength(num size) → String
The rule size list length error message
override
ruleSizeNumber(num size) → String
The rule size number error message
override
ruleSizeStringLength(num size) → String
The rule size string length error message
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited